export const NOTIFICATION_TYPES = {
  IMAGING_REQUEST: 'imaging_request',
  LAB_REQUEST: 'lab_request',
  PHARMACY_NOTE: 'pharmacy_note',
};

export const NOTIFICATION_STATUSES = {
  UNREAD: 'unread',
  READ: 'read',
};
